
#include <stdlib.h>
#include <memory.h>

////////////////////////////////////////////////////////////////////////////////
// export C interface
extern "C" 
void computeGold( float* reference, float* idata, const unsigned int len);

static int float_compare(const void *a, const void *b)
{
	if (*(float*)a < *(float*)b) return -1;
	else if (*(float*)a > *(float*)b) return 1;
	else return 0;
}

////////////////////////////////////////////////////////////////////////////////
//! Compute reference data set
//! Each element is multiplied with the number of threads / array length
//! @param reference  reference data, computed but preallocated
//! @param idata      input data as provided to device
//! @param len        number of elements in reference / idata
////////////////////////////////////////////////////////////////////////////////
void
computeGold( float* reference, float* idata, const unsigned int len) 
{
	memcpy(reference, idata, sizeof(float) * len);
	qsort(reference, len, sizeof(float), float_compare );
}

